@@ -48,14 +48,34 @@ extern node *showsister (node * theNode);
 
 extern int myID;
 
-#ifndef HAS_INDIX
+//#ifndef HAS_INDIX
 #define INDIX(a,b,c) ((a)*(b)+(c))
-#define HAS_INDIX
+//#define HAS_INDIX
+//#endif
+// functions 
+void fill_world_unassigned(world_fmt *world);
+long find_in_unassignedDB(char *nayme, unassigned_fmt **db);
+void empty_world_unassigned(world_fmt *world);
+void remove_node_assigndb(world_fmt * world,node *p);
+void reset_all_assigned_nodes(world_fmt *world);
+void reassign_all_individuals(world_fmt *world);
+void swap_unassigned_nodecollection(world_fmt *world1, world_fmt *world2);
+void reassign_individual(node * node1, long newpop);
+void record_assignment(long locus, world_fmt * world);
+void copy_assignment(world_fmt *world1, world_fmt *world2);
+void add_unassigned(node *p, long locus, world_fmt *world);
+ long reset_unassigned(long index, node *p,  long locus, world_fmt *world);
+void allocate_unassigned(node *p,  long locus, world_fmt *world);
+void  set_unassigned(node * p, world_fmt * world);
+void update_assignment(world_fmt *world);
+void report_unassigned(FILE *file, world_fmt *world);
+long chooseUnassigned (proposal_fmt * proposal);
+#ifdef MPI
+void get_assignments (world_fmt * world, option_fmt * options);
 #endif
 
-long find_in_unassignedDB(char *nayme, unassigned_fmt **db);
-
-void fill_world_unassigned(world_fmt *world, option_fmt *options)
+// function implementations
+void fill_world_unassigned(world_fmt *world)
 {
   //assignment
   world->unassigned = (unassigned_fmt **) mycalloc(1,sizeof(unassigned_fmt*));
@@ -94,11 +114,11 @@ void remove_node_assigndb(world_fmt * world,node *p)
   if (index != UNKNOWN)
     {
       unassigned_fmt *t = world->unassigned[index];
-      for (i=t->ploidy-1; i >= 0; i--)
+      for (i= (long) t->ploidy-1; i >= 0; i--)
 	{
 	  if(p == t->thenodes[i])
 	    {
-	      if (i!=t->ploidy-1)
+	      if (i!= (long) t->ploidy-1)
 		{
 		  t->thenodes[i] = t->thenodes[t->ploidy-1];
 		  t->ploidy -= 1;
@@ -116,8 +136,8 @@ void remove_node_assigndb(world_fmt * world,node *p)
 
 void reset_all_assigned_nodes(world_fmt *world)
 {
-  long i;
-  long j;
+   long i;
+   long j;
   for (i = 1;i < world->unassignednum; i++)
     {
       if (world->unassigned[i]->key != NULL)
@@ -131,11 +151,11 @@ void reset_all_assigned_nodes(world_fmt *world)
 // used with heating
 void reassign_all_individuals(world_fmt *world)
 {
-  long i, j;
+   long i, j;
   //  char *nayme;
   char *key;
-  long ploidy;
-  long testploidy;
+   long ploidy;
+   long testploidy;
   node **thenodes;
   node *thenode;
 #ifdef DEBUG
@@ -191,7 +211,7 @@ void swap_unassigned_nodecollection(world_fmt *world1, world_fmt *world2)
 
 
 //used for origin which is dangling so no migration events need to be considered
-void reassign_individual(world_fmt * world, node * node1, long newpop)
+void reassign_individual(node * node1, long newpop)
 {
   if (node1->type != 't')
     return;
@@ -207,12 +227,12 @@ void reassign_individual(world_fmt * world, node * node1, long newpop)
 
 
 // records a node and its population assignment
-void record_assignment(long locus, world_fmt * world)
+void record_assignment( long locus, world_fmt * world)
 {
-  long j;
-  long index;
+   long j;
+   long index;
   node *p;
-  const long len=world->unassignednum;
+  const  long len=world->unassignednum;
   for (index=1; index < len; index++)
     {
       for(j=0;j<world->unassigned[index]->ploidy;j++)
@@ -220,7 +240,7 @@ void record_assignment(long locus, world_fmt * world)
 	  // this assumes all nodes talk about the same individuals
 	  p = world->unassigned[index]->thenodes[j];
 	  if (p!=NULL)
-	    world->unassigned[index]->probloc[INDIX(world->numpop, locus,p->actualpop)] += 1;
+	    world->unassigned[index]->probloc[INDIX(world->numpop, locus,( long) p->actualpop)] += 1;
 	}
     }
 }
@@ -231,7 +251,7 @@ void record_assignment(long locus, world_fmt * world)
 // tips 
 void copy_assignment(world_fmt *world1, world_fmt *world2)
 {
-  long i,j;
+   long i,j;
   unassigned_fmt *db;
   node * node1, *node2;
 #ifdef DEBUG
@@ -272,47 +292,47 @@ long find_in_unassignedDB(char *nayme, unassigned_fmt **db)
   return d->index; 
 }
 
-long add_unassigned(node *p, long locus, world_fmt *world)
+void add_unassigned(node *p,  long locus, world_fmt *world)
 {
-  const long numpop = world->numpop;
-  long newpop = RANDINT(0,numpop-1);
+  const  long numpop = world->numpop;
+   long newpop = ( long) RANDINT(0,(long) numpop-1);
   unassigned_fmt *temp;
   if (p->type != 't')
     error("node is not tip");
 
   temp = (unassigned_fmt *) mycalloc(1,sizeof(unassigned_fmt));
   temp->key = strdup(p->truename);
-  temp->probloc = (MYREAL *) mycalloc(world->loci * world->numpop, sizeof(MYREAL));
+  temp->probloc = (MYREAL *) mycalloc((size_t) (world->loci * world->numpop), sizeof(MYREAL));
   //temp->probloc[INDIX(world->numpop,locus,newpop)] = 0.0;
   temp->thenodes = (node **) mycalloc(1,sizeof(node *));
   temp->thenodes[0] = p;
-  temp->index = world->unassignednum;
+  temp->index = (long) world->unassignednum;
   temp->lastlocus = locus;
   temp->lastpop = newpop;
   temp->ploidy=1;
 
   world->unassigned[temp->index-1]->next = temp;
   world->unassignednum++;
-  world->unassigned = (unassigned_fmt **) realloc(world->unassigned,sizeof(unassigned_fmt*)*world->unassignednum);
+  world->unassigned = (unassigned_fmt **) myrealloc(world->unassigned,sizeof(unassigned_fmt*)* (size_t) world->unassignednum);
   world->unassigned[temp->index] = temp;
 #ifdef DEBUG 
   printf("%i> added %s (%li) to unassigned db [heat=%f,replicate=%li]\n",myID, temp->key,temp->index, world->heat,
 	 world->replicate);
 #endif
-  return world->unassignednum;
+  //no return value used ever: return world->unassignednum;
 }
 
 // resets the values for a new locus! to zero,
 // but also checks whether this is a diploid etc that will need to have 
 // symmetric updates of population labels for the reassignment
-long reset_unassigned(long index, node *p, long locus, world_fmt *world)
+ long reset_unassigned(long index, node *p,  long locus, world_fmt *world)
 {
-  long replicate = world->replicate;
-  const long numpop = world->numpop;
+  long  replicate = world->replicate;
+  const  long numpop = world->numpop;
   //long pop;
   unassigned_fmt **db = world->unassigned;
   unassigned_fmt *temp = db[index];
-  long newpop = RANDINT(0,numpop-1);
+  long  newpop = ( long) RANDINT(0,(long) numpop-1);
 #ifdef DEBUG
   printf("%i> reset_unassigned()\n", myID);
 #endif
@@ -349,10 +369,10 @@ long reset_unassigned(long index, node *p, long locus, world_fmt *world)
 }
 
 
-void allocate_unassigned(node *p, long locus, world_fmt *world)
+void allocate_unassigned(node *p,  long locus, world_fmt *world)
 {
   long index;
-  long newpop;
+   long newpop;
   index = find_in_unassignedDB(p->truename,world->unassigned);
   if (index == UNKNOWN)
     {
@@ -361,13 +381,13 @@ void allocate_unassigned(node *p, long locus, world_fmt *world)
   else
     {
       newpop = reset_unassigned(index, p, locus, world);
-      p->actualpop = p->pop = newpop; //syncs the individual for diploid data
+      p->actualpop = p->pop = (long) newpop; //syncs the individual for diploid data
     }
 }
 
 void  set_unassigned(node * p, world_fmt * world)
 {
-  long locus = world->locus;
+   long locus = world->locus;
   if (world->has_unassigned)
     {
       if (p->truename[0] == '?')
@@ -381,39 +401,26 @@ void  set_unassigned(node * p, world_fmt * world)
 
 void update_assignment(world_fmt *world)
 {
-  long i;
-  long r = RANDINT(1 , world->unassignednum-1);
+   long i;
+  long r = RANDINT(1 , (long) world->unassignednum-1);
   node ** nodes = world->unassigned[r]->thenodes;
-  long ploidy   = world->unassigned[r]->ploidy;
-  long newpop = RANDINT(0, world->numpop-1);
+   long ploidy   = world->unassigned[r]->ploidy;
+  long newpop = RANDINT(0, (long) world->numpop-1);
   for (i=0; i<ploidy;i++)
     {
-      reassign_individual(world,nodes[i],newpop);
+      reassign_individual(nodes[i], newpop);
+#ifdef DEBUG
+      printf("%i> assignment: old:%li new:%li\n", myID, nodes[i]->actualpop, newpop);
+#endif
     }
 }
 
-#ifdef MPI
-void transfer_unassigned_master(world_fmt *world)
-{
-
-}
-
-void transfer_unassigned_worker(world_fmt *world)
-{
-  //which locus
-  //which replicate
-  //
-}
-
-#endif
-
-
 void report_unassigned(FILE *file, world_fmt *world)
 {
-  long i;
-  long idi;
-  long locus;
-  long pop;
+   long i;
+   long idi;
+   long locus;
+   long pop;
   MYREAL sum = 0.0;
   MYREAL lsum;
   MYREAL *total;
@@ -441,7 +448,7 @@ void report_unassigned(FILE *file, world_fmt *world)
       for (i=1;i<world->unassignednum;i++)
 	{
 	  key = world->unassigned[i]->key;
-	  memset(total,0,sizeof(MYREAL)*world->numpop);
+	  memset(total,0,sizeof(MYREAL)* (size_t) world->numpop);
 	  for (locus=0;locus<world->loci;locus++)
 	    {
 	      fprintf(file, "%-10.10s ",key);
@@ -465,7 +472,7 @@ void report_unassigned(FILE *file, world_fmt *world)
 		}
 	      fprintf(file, "\n");	   
 	    }
-	  maxtotal = -HUGE;
+	  maxtotal = (MYREAL) -HUGE;
 	  for (pop=0;pop<world->numpop;pop++)
 	    {
 	      if (maxtotal < total[pop])
@@ -490,8 +497,7 @@ void report_unassigned(FILE *file, world_fmt *world)
 
 ///
 /// pick a node at random from the unassigned list
-long
-chooseUnassigned (proposal_fmt * proposal)
+long chooseUnassigned (proposal_fmt * proposal)
 {
   //long elem = 0;
   //node *tmp=NULL;//, **goal;
@@ -502,7 +508,7 @@ chooseUnassigned (proposal_fmt * proposal)
     {
       while(index<0 && counter++ < 100)
 	{
-	  index = RANDINT(1,proposal->world->unassignednum-1);
+	  index = RANDINT(1,(long) proposal->world->unassignednum-1);
 	  if (proposal->world->unassigned[index]->thenodes[0]==NULL)
 	    index = -1;
 	}
@@ -516,11 +522,11 @@ chooseUnassigned (proposal_fmt * proposal)
   while(j== -1 && counter++ < 100)
     {
       if(proposal->world->unassigned[index]->ploidy>0)
-	j = RANDINT(0, proposal->world->unassigned[index]->ploidy-1);
+	j = RANDINT(0, (long) proposal->world->unassigned[index]->ploidy-1);
       else
 	{
 	  j = -1;
-	  index = RANDINT(1,proposal->world->unassignednum-1);
+	  index = RANDINT(1,(long) proposal->world->unassignednum-1);
 	}
     }
   if (counter>99)
@@ -553,10 +559,9 @@ chooseUnassigned (proposal_fmt * proposal)
 
 ///
 /// save all population assignments from the worker nodes
-void
-get_assignments (world_fmt * world, option_fmt * options)
-{
 #ifdef MPI
+void get_assignments (world_fmt * world, option_fmt * options)
+{
     long maxreplicate = (options->replicate
                          && options->replicatenum >
                          0) ? options->replicatenum : 1;
@@ -566,5 +571,5 @@ get_assignments (world_fmt * world, option_fmt * options)
         mpi_results_master (MIGMPI_ASSIGN, world, maxreplicate,
                             unpack_assign_buffer);
     }
-#endif
 }
+#endif
