@@ -147,17 +147,17 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL *sums, boolean mrca)
     
     duo ** eventbins;
     
-    float *total;
-    float *meantime;
-    float *mediantime;
-    float *stdtime;
-    float *freq;
-    float *values;
-    float **allvalues=NULL;
-    float ntotal;
-    float eventbinsize;
-    float age;
-    float binfreq;
+    double *total;
+    double *meantime;
+    double *mediantime;
+    double *stdtime;
+    double *freq;
+    double *values;
+    double **allvalues=NULL;
+    double ntotal;
+    double eventbinsize;
+    double age;
+    double binfreq;
 
     eventbinmax = (long *) mycalloc(npp, sizeof(long));
 
@@ -173,16 +173,16 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL *sums, boolean mrca)
                     eventbinmax[pop] = eventbinnum[pop];
               }  
           }
-        allvalues = (float **) mycalloc(npp,sizeof(float*));
+        allvalues = (double **) mycalloc(npp,sizeof(double*));
         for (pop = startpop; pop < endpop; pop++)
           { 
-            allvalues[pop] = (float *) mycalloc(eventbinmax[pop]+1,sizeof(float));
+            allvalues[pop] = (double *) mycalloc(eventbinmax[pop]+1,sizeof(double));
           }
       }
     // initialize the vectors used for the table
-    values = (float *) mycalloc(1, sizeof(float));
-    total = (float *) mycalloc(loci1, sizeof(float));
-    meantime = (float *) mycalloc(loci1pop * 4, sizeof(float));
+    values = (double *) mycalloc(1, sizeof(double));
+    total = (double *) mycalloc(loci1, sizeof(double));
+    meantime = (double *) mycalloc(loci1pop * 4, sizeof(double));
     mediantime = meantime + (loci1pop);
     stdtime = mediantime + (loci1pop);
     freq = stdtime + (loci1pop);
@@ -191,22 +191,22 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL *sums, boolean mrca)
       {
         eventbins = world->mighistloci[locus].migeventbins;
         eventbinnum = world->mighistloci[locus].migeventbinnum;
-        eventbinsize = (float) world->mighistloci[locus].eventbinsize;
+        eventbinsize = (double) world->mighistloci[locus].eventbinsize;
         
         for (pop = startpop; pop < endpop; pop++)
           {
-            age = eventbinsize / 2.0f;
-            values = (float *) myrealloc(values, eventbinnum[pop] * sizeof(float));
+            age = eventbinsize / 2.0;
+            values = (double *) myrealloc(values, eventbinnum[pop] * sizeof(double));
             
             lp = locus * npp + pop;
             
-            meantime[lp] = 0.f;
-            stdtime[lp] = 0.f;
-            freq[lp] = 0.f;
+            meantime[lp] = 0.;
+            stdtime[lp] = 0.;
+            freq[lp] = 0.;
             
             for (i = 0; i < eventbinnum[pop]; i++)
               {
-                binfreq = (float) (eventbins[pop][i][column]);
+                binfreq = (double) (eventbins[pop][i][column]);
                 freq[lp] += binfreq; // total frequency of events per parameter 
                 total[locus] += binfreq; // total of frequency this should add up to world->loci
                 values[i] = binfreq * age; // frequency times age [how many times was this age recorded.]
@@ -241,9 +241,9 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL *sums, boolean mrca)
         for (pop = startpop; pop < endpop; pop++)
           {
             lp = locus * npp + pop;
-            ntotal += (float) sums[lp];
-            freq[lp] =  (float) sums[lp];  
-            stdtime[lp] = (float) sqrt(stdtime[lp]);
+            ntotal += (double) sums[lp];
+            freq[lp] =  (double) sums[lp];  
+            stdtime[lp] = (double) sqrt((double) stdtime[lp]);
           }
         for (pop = startpop; pop < endpop; pop++)
           {
@@ -264,7 +264,7 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL *sums, boolean mrca)
           {
             lp = sumloc * npp + pop;
             //mediantime[lp] = -1.; //DEBUG: allvalues[pop][(long) (eventbinnum[pop]/2)]/freq[lp];
-            stdtime[lp] = (float) sqrt(stdtime[lp]);
+            stdtime[lp] = (double) sqrt((double) stdtime[lp]);
           }
       }
     
@@ -324,9 +324,9 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL *sums, boolean mrca)
                          "%4li %4li    %3.5f    %3.5f    %3.5f    %3.5f\n",
                          frompop + 1,
                          topop + 1,
-                         meantime[lp], mediantime[lp],
-                         stdtime[lp],
-                         freq[lp]);
+                         (double) meantime[lp], (double) mediantime[lp],
+                         (double) stdtime[lp],
+                         (double) freq[lp]);
               }
           }
         FPRINTF (out,
@@ -423,7 +423,7 @@ setup_mig_coal_events (world_fmt * world, option_fmt * options)
     long locus, i, j;
     long allocsize = 1;
     long npall = world->numpop2+ world->bayes->mu + world->species_model_size * 2;
-    MYREAL  binsize = world->options->eventbinsize; // in mutational units (=time scale)
+    MYREAL  binsize = (double) world->options->eventbinsize; // in mutational units (=time scale)
     if (world->options->mighist)
       {
         for (locus = 0; locus < world->loci; locus++)
@@ -513,7 +513,7 @@ void print_event_values_list(FILE *file, long locus, duo **eventbins, MYREAL eve
         age = eventbinsize/2.;
         for(i = 0; i < eventbinnum[pop]; i++)
           {
-            fprintf(file,"%10.10f  %10.10f     %10.10f\n", age, eventbins[pop][i][0], eventbins[pop][i][1]);
+            fprintf(file,"%10.10f  %10.10f     %10.10f\n", age, (double) eventbins[pop][i][0], (double) eventbins[pop][i][1]);
             age += eventbinsize;
           }
       } 
@@ -595,7 +595,7 @@ void print_event_values_tofile(FILE *file,  world_fmt *world)
     MYREAL eventbinsize;
     
     fprintf(file,"# Raw record of the events histogram for all parameters and all loci\n");  
-    fprintf(file,"# The time interval is set to %f\n", world->options->eventbinsize);  
+    fprintf(file,"# The time interval is set to %f\n", (double) world->options->eventbinsize);  
     fprintf(file,"# produced by the program %s (http://popgen.scs.fsu.edu/migrate.hml)\n",
             MIGRATEVERSION);  
     fprintf(file,"# written by Peter Beerli 2006-2014, Tallahassee,\n");
@@ -669,7 +669,7 @@ void print_event_values_tofile(FILE *file,  world_fmt *world)
 		for(i = 0; i < eventbinnum[pop]; i++)
 		  {
 		    fprintf(file,"%li\t%li\t%li\t%10.10f\t%10.10f\t%10.10f\n", 
-			    locus+1, pop+1, i+1, age, eventbins[pop][i][0], eventbins[pop][i][1]);
+			    locus+1, pop+1, i+1, age, (double) eventbins[pop][i][0], (double) eventbins[pop][i][1]);
 		    age += eventbinsize;
 		  }
 	      } 
@@ -710,31 +710,31 @@ void prepare_event_values(world_fmt *world, MYREAL *sums0,MYREAL *sums1)
 		
 		for(i = 0; i < eventbinnum[pop]; i++)
 		  {
-		    if(eventbins[pop][i][0] <= 0.0)
+		    if(eventbins[pop][i][0] <= 0.0f)
 		      {    
 			continue;
 		      }
 		    else
 		      {
-			sum0 += eventbins[pop][i][0];                    
+			sum0 += (double) eventbins[pop][i][0];                    
 		      }
 		    
-		    if(eventbins[pop][i][1] <= 0.0)
+		    if(eventbins[pop][i][1] <= 0.0f)
 		      { 
 			continue;
 		      }
 		    else
 		      {
-			sum1 += eventbins[pop][i][1];
+			sum1 += (double) eventbins[pop][i][1];
 		      }
 		  }
 		// calculate frequency from bincount data
 		for(i = 0; i < eventbinnum[pop]; i++)
 		  {
-		    if(eventbins[pop][i][0] <= 0.0)
+		    if(eventbins[pop][i][0] <= 0.0f)
 		      continue;
 		    eventbins[pop][i][0] /= sum0;
-		    if(eventbins[pop][i][1] <= 0.0)
+		    if(eventbins[pop][i][1] <= 0.0f)
 		      continue;
 		    eventbins[pop][i][1] /= sum1;
 		  }
@@ -766,11 +766,11 @@ void prepare_event_values(world_fmt *world, MYREAL *sums0,MYREAL *sums1)
 	      {
 		for(i=0 ; i < eventbinnum[pop]; i++)
 		  {
-		    if(eventbins[pop][i][0] > 0.0)
+		    if(eventbins[pop][i][0] > 0.0f)
 		      {
 			eventbins_all[pop][i][0] += eventbins[pop][i][0]/world->loci;
 		      }
-		    if(eventbins[pop][i][1] > 0.0)
+		    if(eventbins[pop][i][1] > 0.0f)
 		      {
 			eventbins_all[pop][i][1] += eventbins[pop][i][1]/world->loci;
 		      }
