@@ -144,7 +144,7 @@ void paired_qsort2(pair *x, long xelem)
     elements = 1;
     for(li=1; li < xelem; li++)
     {
-      if(fabs(x[li][1]- x[li-1][1])>FLT_EPSILON)
+      if(fabs(x[li][1]- x[li-1][1])> (double) FLT_EPSILON)
         {
             elements++;
             continue;
@@ -178,6 +178,24 @@ floatcmp (const void *v1, const void *v2)
     }
 }
 
+int
+doublecmp (const void *v1, const void *v2)
+{
+    if (*(const double *) v1 < *(const double *) v2)
+    {
+        return -1;
+    }
+    else
+    {
+        if (*(const double *) v1 > *(const double *) v2)
+        {
+            return 1;
+        }
+        else
+            return 0;
+    }
+}
+
 
 int
 longcmp (const void *v1, const void *v2)
