@@ -1,12 +1,33 @@
 /* speciate.h */
 // contains declarations for speciate.c
 //
-#ifndef __SPECIATE__H
-#define  __SPECIATE__H
+#ifndef SPECIATE_H
+#define SPECIATE_H
+/*
+  Copyright (c) 2015 Peter Beerli
+
+  Permission is hereby granted, free of charge, to any person obtaining a copy
+  of this software and associated documentation files (the "Software"), to deal
+  in the Software without restriction, including without limitation the rights
+  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+  copies of the Software, and to permit persons to whom the Software is
+  furnished to do so, subject to the following conditions:
+
+  The above copyright notice and this permission notice shall be included in
+  all copies or substantial portions of the Software.
+
+  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+  THE SOFTWARE.
+*/
+
 extern MYREAL log_prob_wait_speciate(MYREAL t0, MYREAL t1, MYREAL mu, MYREAL sigma, species_fmt *s);
 extern MYREAL log_point_prob_speciate(MYREAL t1, MYREAL mu, MYREAL sigma, species_fmt * s);
 extern MYREAL eventtime_single(proposal_fmt *proposal, world_fmt *world, long pop, long timeslice, long *lineages, double age, char * event, long *to, long *from);
-
 extern node * set_type2(world_fmt *world, node *p, node *q, char *custm2);
 extern MYREAL set_type(world_fmt *world, long topop, long frompop, char *custm2, long numpop);
 extern long newtree_update (world_fmt * world, long g, boolean assign);
@@ -20,7 +41,7 @@ extern MYREAL wait_event_species(world_fmt *world, vtlist *tli, MYREAL t0, MYREA
 extern MYREAL wait_D(long pop, MYREAL t0, MYREAL t1, long *lineages, world_fmt *world);
 extern void set_first_speciestree(node *mrca, world_fmt *world);
 extern void species_datarecorder(world_fmt *world);
-extern species_fmt * get_species_model(long to, species_fmt * s , long ssize);
+extern species_fmt * get_species_model( long to, species_fmt * s ,  long ssize);
 extern void species_datarecorder(world_fmt *world);
 extern void construct_locusspecies_histogram(world_fmt *world, long locus, MYREAL *mini, MYREAL *maxi, float **results);
 extern void read_species_record(long masternumbinall, MYREAL *params, long *n, MYREAL *oldmeans, MYREAL *lowerbound, MYREAL *upperbound, world_fmt *world, char **inptr);
